searchData={"content_type":"text/markdown","items":[{"doc":"#","ref":"Inngest.html","title":"Inngest","type":"module"},{"doc":"Elixir SDK for **[Inngest](https://www.inngest.com)**","ref":"Inngest.html#module-experimental-non-official-use-at-your-own-risk","title":"Experimental - non official, use at your own risk - Inngest","type":"module"},{"doc":"The Elixir SDK can be downloaded from [Hex](https://hex.pm/packages/inngest). Add it\nto your list of dependencies in `mix.exs`\n\n``` elixir\n# mix.exs\ndef deps do\n  [\n    {:inngest, \"~> 0.1\"}\n  ]\nend\n```\n\n#","ref":"Inngest.html#module-installation","title":"Installation - Inngest","type":"module"},{"doc":"This is a basic example of what an Inngest function will look like.\n\nA Module can be turned into an Inngest function easily by using the `Inngest.Function`\nmacro.\n\n``` elixir\ndefmodule MyApp.AwesomeFunction do\n  use Inngest.Function,\n    name: \"awesome function\", # The name of the function\n    event: \"func/awesome\"     # The event this function will react to\n\n  # Declare a \"run\" macro that runs contains the business logic\n  run \"hello world\" do\n    {:ok, %{result: \"hello world\"}}\n  end\nend\n```\n\nThe Elixir SDK follows `ExUnit`'s pattern of accumulative macros, where each block\nis a self contained piece of logic.\n\nYou can declare multiple blocks of `run` or other available macros, and the function\nwill execute the code in the order it is declared.\n\n##","ref":"Inngest.html#module-example","title":"Example - Inngest","type":"module"},{"doc":"Here's a slightly more complicated version, which should provide you an idea what is\ncapable with Inngest.\n\n``` elixir\ndefmodule MyApp.AwesomeFunction do\n  use Inngest.Function,\n    name: \"awesome function\", # The name of the function\n    event: \"func/awesome\"     # The event this function will react to\n\n  # An Inngest function will automatically retry when it fails\n\n  # \"run\" is a normal unit execution. It is not memorized and will be\n  # executed every time the function gets re-invoked.\n  #\n  # The return \"data\" from each execution block will be accumulated\n  # and passed on to the next execution\n  run \"1st run\" do\n    {:ok, %{run: \"do something\"}}\n  end\n\n  # \"step\" is a unit execution where the return value will be memorized.\n  # An already executed \"step\" will not be executed again when re-invoked\n  # and will use the previously returned value\n  #\n  # e.g. The previous `%{run: \"do something\"}` can be extracted out via\n  # pattern matching, just like how you do it in `ExUnit`\n  step \"1st step\", %{data: %{run: output}} do\n    {:ok, %{hey: output}}\n  end\n\n  # \"sleep\" will pause the execution for the declared amount of duration.\n  sleep \"2s\"\n\n  step \"2nd step\" do\n    {:ok, %{yo: \"lo\"}}\n  end\n\n  # \"sleep\" can also sleep until a valid datetime string\n  sleep \"until July 31 2023 - 8pm\", do: \"2023-07-18T07:31:00Z\"\n\n  # \"wait_for_event\" will pause the function execution until the declared\n  # event is received\n  wait_for_event \"test/wait\", do: [timeout: \"1d\", match: \"data.yo\"]\n\n  step \"result\", %{data: data} do\n    {:ok, %{result: data}}\n  end\nend\n```\n\nSee the **[guides](https://hexdocs.pm/inngest)** for more details regarding use cases and how each macros can be used.","ref":"Inngest.html#module-advanced","title":"Advanced - Inngest","type":"module"},{"doc":"","ref":"Inngest.html#send/1","title":"Inngest.send/1","type":"function"},{"doc":"Module representing an Inngest client (subject to change).","ref":"Inngest.Client.html","title":"Inngest.Client","type":"module"},{"doc":"Retrieves the registration information from the Dev server.","ref":"Inngest.Client.html#dev_info/0","title":"Inngest.Client.dev_info/0","type":"function"},{"doc":"Returns an HTTP client for making requests against Inngest.","ref":"Inngest.Client.html#httpclient/2","title":"Inngest.Client.httpclient/2","type":"function"},{"doc":"Send one or a batch of events to Inngest","ref":"Inngest.Client.html#send/2","title":"Inngest.Client.send/2","type":"function"},{"doc":"Module representing an Inngest event.","ref":"Inngest.Event.html","title":"Inngest.Event","type":"module"},{"doc":"Construct an Event struct from a map.","ref":"Inngest.Event.html#from/1","title":"Inngest.Event.from/1","type":"function"},{"doc":"","ref":"Inngest.Event.html#t:t/0","title":"Inngest.Event.t/0","type":"type"},{"doc":"Module to be used within user code to setup an Inngest function.\nMaking it servable and invokable.","ref":"Inngest.Function.html","title":"Inngest.Function","type":"behaviour"},{"doc":"Returns the function name","ref":"Inngest.Function.html#c:name/0","title":"Inngest.Function.name/0","type":"callback"},{"doc":"","ref":"Inngest.Function.html#register_step/6","title":"Inngest.Function.register_step/6","type":"function"},{"doc":"Defines a normal execution block with a `message` that is non-deterministic.\n\nMeaning whenever Inngest asks the SDK to execute, the code block wrapped\nwithin `run` will always run, no pun intended.\n\nHence making it non deterministic, since each execution can yield a different\nresult.\n\nThis is best for things that do not need idempotency. The result here will be\npassed on to the next execution unit.\n\n##","ref":"Inngest.Function.html#run/3","title":"Inngest.Function.run/3","type":"macro"},{"doc":"It accepts an optional `map` that includes\n\n- `event`\n- `data`\n\n##","ref":"Inngest.Function.html#run/3-arguments","title":"Arguments - Inngest.Function.run/3","type":"macro"},{"doc":"@spec :ok | {:ok, map()} | {:error, map()}\n\nwhere the data is a `map` accumulated with outputs from previous executions.","ref":"Inngest.Function.html#run/3-expected-output-types","title":"Expected output types - Inngest.Function.run/3","type":"macro"},{"doc":"run \"non deterministic code block\", %{event: event, data: data} do\n      # do\n      # something\n      # here\n\n      {:ok, %{result: result}}\n    end","ref":"Inngest.Function.html#run/3-examples","title":"Examples - Inngest.Function.run/3","type":"macro"},{"doc":"Set a duration to pause the execution of your function.\n\nValid durations are combination of\n- `s` - second\n- `m` - minute\n- `h` - hour\n- `d` - day","ref":"Inngest.Function.html#sleep/1","title":"Inngest.Function.sleep/1","type":"macro"},{"doc":"sleep \"2s\"\n    sleep \"1d\"\n    sleep \"5m\"\n    sleep \"1h30m\"","ref":"Inngest.Function.html#sleep/1-examples","title":"Examples - Inngest.Function.sleep/1","type":"macro"},{"doc":"Pauses the function execution until the specified DateTime.\n\nExpected valid datetime string formats are:\n- `RFC3389`\n- `RFC1123`\n- `RFC882`\n- `UNIX`\n- `ANSIC`\n- `ISOdate`","ref":"Inngest.Function.html#sleep/3","title":"Inngest.Function.sleep/3","type":"macro"},{"doc":"sleep \"sleep until 2023-10-25\", %{event: event, data: data} do\n      # do something to caculate time\n\n      # return the specified time that it should sleep until\n      \"2023-07-18T07:31:00Z\"\n    end","ref":"Inngest.Function.html#sleep/3-examples","title":"Examples - Inngest.Function.sleep/3","type":"macro"},{"doc":"Returns the function's human-readable ID, such as \"sign-up-flow\"","ref":"Inngest.Function.html#c:slug/0","title":"Inngest.Function.slug/0","type":"callback"},{"doc":"Defines a deterministic execution block with a `message`.\n\nThis is exactly the same as `Inngest.Function.run/3`, except the code within\nthe `step` blocks are always guaranteed to be executed once.\n\nSubsequent calls to the SDK will not execute and uses the previously executed\nresult.\n\nIf the code block returns an error or raised an exception, it will be retried.\n\n##","ref":"Inngest.Function.html#step/3","title":"Inngest.Function.step/3","type":"macro"},{"doc":"It accepts an optional `map` that includes\n\n- `event`\n- `data`\n\n##","ref":"Inngest.Function.html#step/3-arguments","title":"Arguments - Inngest.Function.step/3","type":"macro"},{"doc":"@spec :ok | {:ok, map()} | {:error, map()}\n\nwhere the data is a `map` accumulated with outputs from previous executions.","ref":"Inngest.Function.html#step/3-expected-output-types","title":"Expected output types - Inngest.Function.step/3","type":"macro"},{"doc":"step \"idempotent code block\", %{event: event, data: data} do\n      # do\n      # something\n      # here\n\n      {:ok, %{result: result}}\n    end","ref":"Inngest.Function.html#step/3-examples","title":"Examples - Inngest.Function.step/3","type":"macro"},{"doc":"Returns the event name or schedule that triggers the function","ref":"Inngest.Function.html#c:trigger/0","title":"Inngest.Function.trigger/0","type":"callback"},{"doc":"","ref":"Inngest.Function.html#validate_datetime/1","title":"Inngest.Function.validate_datetime/1","type":"function"},{"doc":"Pause function execution until a particular event is received before continuing.\n\nIt returns the accepted event object or `nil` if the event is not received within\nthe timeout.\n\nThe event name will be used as the key for storing the returned event for subsequent\nexecution units.","ref":"Inngest.Function.html#wait_for_event/3","title":"Inngest.Function.wait_for_event/3","type":"macro"},{"doc":"wait_for_event \"auth/signup.email.confirmed\", %{event: event, data: data} do\n      match = \"user.id\"\n      [timeout: \"1d\", if: \"event.#{match} == async.#{match}\"]\n    end\n\n    # or in a shorter version\n    wait_for_event \"auth/signup.email.confirmed\", do: [timeout: \"1d\", match: \"user.id\"]","ref":"Inngest.Function.html#wait_for_event/3-examples","title":"Examples - Inngest.Function.wait_for_event/3","type":"macro"},{"doc":"A struct that keeps info about function, and\nhandles the invoking of steps","ref":"Inngest.Function.Handler.html","title":"Inngest.Function.Handler","type":"module"},{"doc":"Handles the invoking of steps and runs from the executor","ref":"Inngest.Function.Handler.html#invoke/2","title":"Inngest.Function.Handler.invoke/2","type":"function"},{"doc":"","ref":"Inngest.Function.Handler.html#t:t/0","title":"Inngest.Function.Handler.t/0","type":"type"},{"doc":"A struct representing a function step","ref":"Inngest.Function.Step.html","title":"Inngest.Function.Step","type":"module"},{"doc":"","ref":"Inngest.Function.Step.html#t:t/0","title":"Inngest.Function.Step.t/0","type":"type"},{"doc":"Struct representing a function trigger.\n\nCan either be an `event` or a `cron`, and they're mutually exclusive.","ref":"Inngest.Function.Trigger.html","title":"Inngest.Function.Trigger","type":"module"},{"doc":"# defining an event trigger\n    %Inngest.Function.Trigger{event: \"auth/signup.email\"}\n\n    # defining a cron trigger, and can accept a timezone\n    %Inngest.Function.Trigger{cron: \"TZ=America/Los_Angeles * * * * *\"}","ref":"Inngest.Function.Trigger.html#module-examples","title":"Examples - Inngest.Function.Trigger","type":"module"},{"doc":"","ref":"Inngest.Function.Trigger.html#t:t/0","title":"Inngest.Function.Trigger.t/0","type":"type"},{"doc":"Router module for Inngest to be integrated with apps that\nhave a router.\n\nCurrently available options are\n- `Phoenix`\n- `Plug.Router`","ref":"Inngest.Router.html","title":"Inngest.Router","type":"module"},{"doc":"use Inngest.Router, :phoenix\n    use Inngest.Router, :plug","ref":"Inngest.Router.html#module-examples","title":"Examples - Inngest.Router","type":"module"},{"doc":"","ref":"Inngest.Router.html#phoenix/0","title":"Inngest.Router.phoenix/0","type":"function"},{"doc":"","ref":"Inngest.Router.html#plug/0","title":"Inngest.Router.plug/0","type":"function"},{"doc":"Router module expected to be used with a `Phoenix` router.","ref":"Inngest.Router.Phoenix.html","title":"Inngest.Router.Phoenix","type":"module"},{"doc":"use Inngest.Router, :phoenix","ref":"Inngest.Router.Phoenix.html#module-examples","title":"Examples - Inngest.Router.Phoenix","type":"module"},{"doc":"","ref":"Inngest.Router.Phoenix.html#inngest/2","title":"Inngest.Router.Phoenix.inngest/2","type":"macro"},{"doc":"Router module expected to be used with a `Plug.Router`.","ref":"Inngest.Router.Plug.html","title":"Inngest.Router.Plug","type":"module"},{"doc":"use Inngest.Router, :plug","ref":"Inngest.Router.Plug.html#module-examples","title":"Examples - Inngest.Router.Plug","type":"module"},{"doc":"","ref":"Inngest.Router.Plug.html#inngest/2","title":"Inngest.Router.Plug.inngest/2","type":"macro"},{"doc":"Handles signature related operations","ref":"Inngest.Signature.html","title":"Inngest.Signature","type":"module"},{"doc":"","ref":"Inngest.Signature.html#hashed_signing_key/1","title":"Inngest.Signature.hashed_signing_key/1","type":"function"},{"doc":"","ref":"Inngest.Signature.html#normalize_key/1","title":"Inngest.Signature.normalize_key/1","type":"function"},{"doc":"","ref":"Inngest.Signature.html#sign/3","title":"Inngest.Signature.sign/3","type":"function"},{"doc":"","ref":"Inngest.Signature.html#signing_key_valid?/4","title":"Inngest.Signature.signing_key_valid?/4","type":"function"},{"doc":"Configuration settings for Inngest. Order of configuration to be read:\n\n1. Environment variables\n2. Application configs\n3. Default values","ref":"Inngest.Config.html","title":"Inngest.Config","type":"module"},{"doc":"","ref":"Inngest.Config.html#app_host/0","title":"Inngest.Config.app_host/0","type":"function"},{"doc":"","ref":"Inngest.Config.html#app_name/0","title":"Inngest.Config.app_name/0","type":"function"},{"doc":"","ref":"Inngest.Config.html#env/0","title":"Inngest.Config.env/0","type":"function"},{"doc":"","ref":"Inngest.Config.html#event_key/0","title":"Inngest.Config.event_key/0","type":"function"},{"doc":"","ref":"Inngest.Config.html#event_url/0","title":"Inngest.Config.event_url/0","type":"function"},{"doc":"","ref":"Inngest.Config.html#inngest_env/0","title":"Inngest.Config.inngest_env/0","type":"function"},{"doc":"","ref":"Inngest.Config.html#inngest_url/0","title":"Inngest.Config.inngest_url/0","type":"function"},{"doc":"","ref":"Inngest.Config.html#is_dev/0","title":"Inngest.Config.is_dev/0","type":"function"},{"doc":"","ref":"Inngest.Config.html#register_url/0","title":"Inngest.Config.register_url/0","type":"function"},{"doc":"","ref":"Inngest.Config.html#sdk_version/0","title":"Inngest.Config.sdk_version/0","type":"function"},{"doc":"","ref":"Inngest.Config.html#signing_key/0","title":"Inngest.Config.signing_key/0","type":"function"},{"doc":"","ref":"Inngest.Config.html#version/0","title":"Inngest.Config.version/0","type":"function"},{"doc":"A custom Plug parser for caching raw request body","ref":"Inngest.CacheBodyReader.html","title":"Inngest.CacheBodyReader","type":"module"},{"doc":"","ref":"Inngest.CacheBodyReader.html#read_body/2","title":"Inngest.CacheBodyReader.read_body/2","type":"function"},{"doc":"","ref":"Inngest.CacheBodyReader.html#read_cached_body/1","title":"Inngest.CacheBodyReader.read_cached_body/1","type":"function"},{"doc":"# How does it work?\n\nCheck **[here][inngest]** to see how Inngest works.\n\n[inngest]: https://www.inngest.com/product/how-inngest-works?ref=elixir-sdk","ref":"how-it-works.html","title":"How does it work?","type":"extras"},{"doc":"# Installation\n\nThe Elixir SDK can be downloaded from [Hex][hex]. Add it to your list of dependencies\nin `mix.exs`:\n\n``` elixir\n# mix.exs\ndef deps do\n  [\n    {:inngest, \"~> 0.1\"}\n  ]\nend\n```\n\nThen run `mix deps.get` to download the package.","ref":"installation.html","title":"Installation","type":"extras"},{"doc":"#","ref":"installation.html#note","title":"Note - Installation","type":"extras"},{"doc":"The Elixir SDK currently uses `Tesla` for handling HTTP requests. While this might\nnot be ideal for some folks, it's the only option that can swap out the underlying HTTP\nlibraries while still providing a similar interface.\n\nUntil there's either a standard `Protocol` defined for handling HTTP calls or HTTP libraries\nactually being standardized, or a better way of abstracting the HTTP interfaces away, `Tesla`\nwill likely be here to stay.\n\n#","ref":"installation.html#http-client","title":"HTTP client - Installation","type":"extras"},{"doc":"If you currently have a preferred adapter you want to use, please take a look at their\n[Adapters][tesla-adapters] page.\n\nOtherwise, it will utilize the default `Hackney` adapter.\n\n[hex]: https://hex.pm/packages/inngest\n[tesla-adapters]: https://hexdocs.pm/tesla/1.7.0/readme.html#adapters","ref":"installation.html#tesla-adapters","title":"Tesla adapters - Installation","type":"extras"},{"doc":"# Create functions\n\nCreating an Inngest function is as easy as using `Inngest.Function`. It creates\nthe necessary attributes and handlers it needs to work with Inngest.\n\n``` elixir\ndefmodule MyApp.Inngest.SomeJob do\n  use Inngest.Function,\n    name: \"some job\",\n    event_name: \"job/foobar\"\nend\n```\n\n- [Configuration](#configuration)\n- [Trigger](#trigger)\n- [Handler](#handler)","ref":"create-function.html","title":"Create functions","type":"extras"},{"doc":"The `Inngest.Function` macro accepts the following options.\n\n##","ref":"create-function.html#configuration","title":"Configuration - Create functions","type":"extras"},{"doc":"A unique identifier for your function to override the default name.\nAlso known in technical terms, a `slug`.\n\n##","ref":"create-function.html#id-string-optional","title":"id - string (optional) - Create functions","type":"extras"},{"doc":"A unique name for your function. This will be used to create a unique\nslug id by default if `id` is not provided.","ref":"create-function.html#name-string-required","title":"name - string (required) - Create functions","type":"extras"},{"doc":"A trigger is exactlyi what the name says. It's the thing that triggers a function\nto run. One of the following is required, and they're mutually exclusive.\n\n##","ref":"create-function.html#trigger","title":"Trigger - Create functions","type":"extras"},{"doc":"The name of the event that will trigger this event to run.\nWe recommend it to name it with a prefix so it's a easier pattern to identify\nwhat it's for.\n\ne.g. `auth/signup.email.send`\n\n##","ref":"create-function.html#event_name-string","title":"event_name - string - Create functions","type":"extras"},{"doc":"A [unix-cron](https://crontab.guru/) compatible schedule string.\n\nOptional timezone prefix, e.g. `TZ=Europe/Paris 0 12 * * 5`.","ref":"create-function.html#cron-string","title":"cron - string - Create functions","type":"extras"},{"doc":"The handlers are your code that runs whenever the trigger occurs.\n\n``` elixir\ndefmodule MyApp.Inngest.SomeJob do\n  use Inngest.Function,\n    name: \"some job\",\n    event_name: \"job/foobar\"\n\n  # This will run when an event `job/foobar` is received\n  run \"do something\", %{event: event, data: data} do\n    # do\n    # some\n    # stuff\n\n    {:ok, %{result: result}} # returns a map as a result\n  end\nend\n```\n\nUnlike some other SDKs, the Elixir SDK follows the pattern `ExUnit` is using.\nEssentially providing a DSL that wraps your logic, making them deterministic.\n\nAll handlers can be repeated, and they will be executed in the order they're\ndeclared:\n\n- `Inngest.Function.run/3` - Run code non-deterministically, executing every time the function is triggered\n- `Inngest.Function.step/3` - Run code deterministically, and individually retryable.\n- `Inngest.Function.sleep/1` or `Inngest.Function.sleep/3` - Sleep for a given amount of time or until a given time.\n- `Inngest.Function.wait_for_event/3` - Pause a function's execution until another event is received.","ref":"create-function.html#handlers","title":"Handlers - Create functions","type":"extras"},{"doc":"# Events\n\nAs you might guess, `Events` are the fundamentals of an event driven system. Inngest starts and\nends with events. An event is the trigger for functions to start, resume and can also hold the\ndata for functions to operate on.\n\nAn `Inngest.Event` looks like this:\n\n```\n%{\n  id: \"\",\n  name: \"event/awesome\",\n  data: { \"hello\": \"world\" },\n  user: { \"external_id\": 10000 },\n  ts: 1690156151,\n  v: \"2023.04.14.1\"\n}\n```\n\n#### `id` - string (optional)\n\nThe `id` field in an event payload is used for deduplication. Setting this field will make\nsure that only one of the events (the first one) with a similar `id` is processed.\n\n#### `name` - string (required)\n\nThe name of the event. We recommend using lowercase dot notation for names, prepending\n` /` with a slash for organization.\n\n#### `data` - map (required)\n\nAny data to associate with the event. Will be serialized as JSON.\n\n#### `user` - map (optional)\n\nAny relevant user identifying data or attributes associated with the event. **This data is\nencrypted at rest**. Use the `external_id` as the identifier. A common example is the `user_id`\nin your system.\n\n#### `ts` - integer (optional)\n\nA timestamp integer representing the unix time (in milliseconds) at which the event occurred.\nDefaults to the time the Inngest receives the event if not provided.\n\n#### `v` - string (optional)\n\nA version identifier for a particular event payload. e.g. `2023-04-14.1`","ref":"events.html","title":"Events","type":"extras"},{"doc":"Use `Inngest.Client.send/1` or you can send it via `curl`:\n\n``` sh\ncurl -X \\\n  POST 'http://127.0.0.1:8288/e/test' \\\n  -d '{ \"name\": \"test/event\", \"data\": { \"hello\": \"world\" } }'\n```","ref":"events.html#sending-events","title":"Sending events - Events","type":"extras"},{"doc":"# Dev server\n\n![Dev server screenshot](https://github.com/darwin67/ex_inngest/assets/5746693/d8b80b54-5238-4c4b-bf76-6e15bee590a7)\n\nInngest provides a dev server you can run locally to aid with local development. You\ncan start the Dev server with:\n\n```sh\nnpx inngest-cli@latest dev\n```\n\nThis will download the latest version available and you should be able to access it\nvia http://localhost:8288.\n\nIf you prefer to download the CLI locally:\n\n```sh\nnpm i -g inngest-cli\n# or\nnpm i -g inngest-cli@ \n```\n\nthen:\n\n``` sh\ninngest-cli dev\n```","ref":"dev-server.html","title":"Dev server","type":"extras"},{"doc":"The Dev server will try to auto discover apps and functions via `http://localhost:3000/api/inngest`\nby default. However, apps like Phoenix typically runs on port `4000`. You can provide the auto\ndiscovery URL when starting the Dev server:\n\n``` sh\nnpx inngest-cli@latest dev -u http://127.0.0.1:4000/api/inngest\n```\n\nThis will tell the Dev server to look at `http://127.0.0.1:4000/api/inngest` to discover and\nregister apps/functions.","ref":"dev-server.html#auto-discovery","title":"Auto discovery - Dev server","type":"extras"},{"doc":"For more options with the `Dev server`, use the `--help` option:\n\n```bash\ninngest-cli dev --help\n```\n\n#","ref":"dev-server.html#other-options","title":"Other options - Dev server","type":"extras"},{"doc":"The `inngest-cli` is a single executable binary. It's packaged and distributed with NPM for\nthe time being, but could change in the future.","ref":"dev-server.html#note","title":"Note - Dev server","type":"extras"},{"doc":"# Serving the API\n\nInngest works by serving an HTTP API endpoint which exposes your functions for us to\ncall on-demand. The first thing you'll need to do is to add and serve the Inngest API\nin your project.","ref":"serve-api.html","title":"Serving the API","type":"extras"},{"doc":"The Elixir SDK provides an `inngest` macro, that will setup the required API endpints\nto your router. The recommended path is `/api/inngest` since it makes it obvious where\nthe endpoints are, but you can change it to whatever you see fit.\n\n``` elixir\ndefmodule MyApp.Router do\n  use Inngest.Router, :plug\n\n  inngest(\"/api/inngest\", path: \"inngest/**/*.ex\")\nend\n```\n\nThere are 2 routers available based on what you're using for exposing HTTP endpoints for\nyour apps:\n\n- `Inngest.Router.Plug`\n- `Inngest.Router.Phoenix`","ref":"serve-api.html#setting-up","title":"Setting up - Serving the API","type":"extras"},{"doc":"# How to deploy\n\nCheck **[here][inngest]** to see how to deploy.\n\n[inngest]: https://www.inngest.com/docs/deploy?ref=elixir-sdk","ref":"deploy.html","title":"How to deploy","type":"extras"},{"doc":"# Working with environments\n\nCheck **[here][inngest]** to see how to work with environments.\n\n[inngest]: https://www.inngest.com/docs/platform/environments?ref=elixir-sdk","ref":"environments.html","title":"Working with environments","type":"extras"},{"doc":"# Creating an Event key\n\nCheck **[here][inngest]** to see how to create an event key.\n\n[inngest]: https://www.inngest.com/docs/events/creating-an-event-key?ref=elixir-sdk","ref":"event-key.html","title":"Creating an Event key","type":"extras"},{"doc":"# Usage Limits\n\nCheck **[here][inngest]** to see how to understand usage limits.\n\n[inngest]: https://www.inngest.com/docs/usage-limits/inngest?elixir-sdk","ref":"limits.html","title":"Usage Limits","type":"extras"},{"doc":"","ref":"changelog.html","title":"CHANGELOG","type":"extras"}]}